@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Parse the UCI Bach choral harmony data set
 
-our $VERSION = '0.0202';
+our $VERSION = '0.0203';
 
 use Moo;
 use strictures 2;
@@ -204,7 +204,7 @@ sub _search_param {
         my %and_notes = ();
         for my $event ( @{ $self->data->{$id}{events} } ) {
             if ( $and ) {
-                for my $note ( sort keys %notes ) {
+                for my $note ( keys %notes ) {
                     if ( $note eq $event->{$name} ) {
                         $and_notes{$note}++;
                     }
@@ -246,7 +246,7 @@ Music::BachChoralHarmony - Parse the UCI Bach choral harmony data set
 
 =head1 VERSION
 
-version 0.0202
+version 0.0203
 
 =head1 SYNOPSIS
 
